@@ -6,18 +6,24 @@ from json import JSONDecodeError
 from typing import Dict, Union
 
 import boto3
-from botocore.exceptions import ClientError
+import botocore
+from botocore.exceptions import ClientError, EndpointConnectionError
 
 from amazon_sagemaker_sql_execution.exceptions import (
     SecretsRetrieverError,
 )
+from amazon_sagemaker_sql_execution.utils.constants import USE_DUALSTACK_ENDPOINT
+from amazon_sagemaker_sql_execution.utils.exception_utils import handle_endpoint_connection_error
 
 
 class AWSSecretsRetriever:
     @staticmethod
     def get_secret_string(secret_name: str, region_name: str = None) -> Dict:
         session = boto3.session.Session()
-        client = session.client(service_name="secretsmanager", region_name=region_name)
+        cfg = botocore.client.Config(
+            use_dualstack_endpoint=USE_DUALSTACK_ENDPOINT,
+        )
+        client = session.client(service_name="secretsmanager", region_name=region_name, config=cfg)
 
         try:
             get_secret_value_response = client.get_secret_value(SecretId=secret_name)
@@ -27,6 +33,8 @@ class AWSSecretsRetriever:
             return secret_dict
         except KeyError:
             raise SecretsRetrieverError(f"`SecretString` was not present in secret {secret_name}")
+        except EndpointConnectionError as error:
+            handle_endpoint_connection_error(error)
         except ClientError as e:
             if e.response["Error"]["Code"] == "ResourceNotFoundException":
                 raise SecretsRetrieverError(f"Secret {secret_name} not found") from e
